#
# spec file for package python-smart-open
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-smart-open
Version:        7.0.5
Release:        2.2
Summary:        Python utils for streaming large files
License:        MIT
URL:            https://github.com/piskvorky/smart_open
Source:         https://github.com/piskvorky/smart_open/archive/refs/tags/v%{version}.tar.gz#/smart_open-%{version}.tar.gz
# PATCH-FIX-UPSTREAM gh#piskvorky/smart_open#847
Patch0:         support-python-313.patch
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-azure-common
Requires:       python-azure-core
Requires:       python-azure-storage-blob
Requires:       python-boto3
Requires:       python-google-cloud-storage
Requires:       python-requests
Requires:       python-wrapt
Requires:       python-zstandard
Suggests:       python-paramiko
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module azure-common}
BuildRequires:  %{python_module azure-core}
BuildRequires:  %{python_module azure-storage-blob}
BuildRequires:  %{python_module boto3}
BuildRequires:  %{python_module google-cloud-storage}
BuildRequires:  %{python_module moto >= 1.3.4}
BuildRequires:  %{python_module moto-server}
BuildRequires:  %{python_module paramiko}
BuildRequires:  %{python_module pytest-rerunfailures}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module requests}
BuildRequires:  %{python_module responses}
BuildRequires:  %{python_module zstandard}
# /SECTION
%python_subpackages

%description
Python utils for streaming large files.
Includes support for S3, HDFS, gzip, bz2, etc.

%prep
%autosetup -p1 -n smart_open-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitelib}/smart_open
%{python_sitelib}/smart_open-%{version}.dist-info

%changelog
* Mon Dec 16 2024 Steve Kowalik <steven.kowalik@suse.com>
- Remove upper pin on urllib3.
- Drop moto_server set up and teardown, it is for one testcase.
- Drop patch skip-gzip-tests-python312.patch, not required.
- Add patch support-python-313.patch:
  * Support Python 3.13 changes.
* Wed Oct 30 2024 Dirk Müller <dmueller@suse.com>
- update to 7.0.5:
  * Fix zstd compression in ab mode
  * Fix close function not neing able to upload a compressed S3
  * Fix test_http.request_callback
  * Update readline logic for azure to match s3
  * Make http handler take an optional requests.Session
  * Ensure no side effects on SinglepartWriter exception
  * Add support for `get_blob_kwargs` to GCS blob read operations
* Thu May  2 2024 Dirk Müller <dmueller@suse.com>
- update to 7.0.4:
  * Fix wb mode with zstd compression (PR #815, @djudd)
  * Remove GCS bucket.exists call to avoid storage.buckets.get
    permission (PR #813, @ddelange)
  * add support for zst writing (PR #812, @mpenkov)
  * roll back PR #812, restore compatibility with built-in open
    function (@mpenkov)
* Thu Mar 21 2024 Dirk Müller <dmueller@suse.com>
- update to 7.0.2:
  * Add `__next__` method to FileLikeProxy
  * Fix python_requires minimum python version in setup.py
  * Add activity check to cached sftp connections
* Wed Mar 20 2024 Steve Kowalik <steven.kowalik@suse.com>
- Do not kill moto_server three minutes into the testsuite. (bsc#1221663)
* Mon Mar 18 2024 Bernhard Wiedemann <bwiedemann@suse.com>
- Avoid stuck build on failing test
* Fri Mar 15 2024 Steve Kowalik <steven.kowalik@suse.com>
- Update to 7.0.1:
  * Do not touch botocore unless it is installed
  * Upgrade dev status classifier to stable
  * Add zstandard compression support
  * Support moto 4 & 5
  * Add logic for handling large files in MultipartWriter uploads to S3
  * Add support for SSH connection via aliases from ~/.ssh/config
  * Secure the connection using SSL when connecting to the FTPS server
  * Make GCS I/O 1000x faster by avoiding unnecessary API call
  * Retry finalizing multipart S3 upload
  * Handle exceptions during writes to Azure
  * Fix str method in SinglepartWriter
  * Fix KeyError: 'ContentRange' when received full content from S3
  * Propagate exit call to the underlying filestream
- Switch to autosetup and pyproject macros.
- Less globs in %%files.
- Update all URLs, the github repository owner has changed.
- Add patch skip-gzip-tests-python312.patch, skip broken tests under
  Python 3.12.
* Thu Oct 12 2023 Ondřej Súkup <mimi.vx@gmail.com>
- Update to 6.4.0
- force require urllib3 < 2 because of https://github.com/RaRe-Technologies/smart_open/issues/784
  * Ignore S3 seeks to the current position (PR #782, @beck3905
  * Set binary mode prior to FTP write ()PR #781, @beck3905)
  * Improve S3 URI Parsing for URIs with "@", "/", and ":" (PR #776, @rileypeterson)
  * Add python 3.11 to setup.py (PR #775, @tooptoop4)
  * Fix retrieving empty but existing object from S3 (PR #771, @Darkheir)
  * Avoid overfilling buffer when reading from Azure (PR #767, @ronreiter)
  * Add required import for example to work (PR #756, @jensenbox)
* Fri Jan  6 2023 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 6.3.0
  * Refactor Google Cloud Storage to use blob.open (ddelange, #744)
  * Add FTP/FTPS support (#33) (RachitSharma2001, #739)
  * Bring back compression_wrapper(filename) + use case-insensitive extension matching (piskvorky, #737)
  * Fix avoidable S3 race condition (#693) (RachitSharma2001, #735)
  * setup.py: Remove pathlib2 (jayvdb, #733)
  * Add flake8 config globally (cadnce, #732)
  * Added buffer_size parameter to http module (mullenkamp, #730)
  * Added documentation to support GCS anonymously (cadnce, #728)
  * Reconnect inactive sftp clients automatically (Kache, #719)
* Sat Oct 15 2022 John Vandenberg <jayvdb@gmail.com>
- Update to v6.2.0
* Fri Sep 18 2020 John Vandenberg <jayvdb@gmail.com>
- Activate test suite
- Update to v2.2.1
* Wed Dec 25 2019 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v1.9.0
